package de.intevation.flys.exports;


import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.intevation.artifactdatabase.state.Attribute;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class AxisSection extends TypeSection {

    public static final String IDENTIFIER_ATTR = "id";
    public static final String LABEL_ATTR      = "label";
    public static final String FONTSIZE_ATTR   = "font-size";
    public static final String FIXATION_ATTR   = "fixation";
    public static final String UPPERRANGE_ATTR = "upper";
    public static final String LOWERRANGE_ATTR = "lower";


    public AxisSection() {
        super("axis");
    }


    public void setIdentifier(String identifier) {
        setStringValue(IDENTIFIER_ATTR, identifier);
    }


    public String getIdentifier() {
        return getStringValue(IDENTIFIER_ATTR);
    }


    public void setLabel(String label) {
        setStringValue(LABEL_ATTR, label);
    }


    public String getLabel() {
        return getStringValue(LABEL_ATTR);
    }


    public void setFontSize(int fontSize) {
        if (fontSize <= 0) {
            return;
        }

        setIntegerValue(FONTSIZE_ATTR, fontSize);
    }


    public Integer getFontSize() {
        return getIntegerValue(FONTSIZE_ATTR);
    }


    public void setFixed(boolean fixed) {
        setBooleanValue(FIXATION_ATTR, fixed);
    }


    public Boolean isFixed() {
        return getBooleanValue(FIXATION_ATTR);
    }


    public void setUpperRange(double upperRange) {
        setDoubleValue(UPPERRANGE_ATTR, upperRange);
    }


    public Double getUpperRange() {
        return getDoubleValue(UPPERRANGE_ATTR);
    }


    public void setLowerRange(double lowerRange) {
        setDoubleValue(LOWERRANGE_ATTR, lowerRange);
    }


    public Double getLowerRange() {
        return getDoubleValue(LOWERRANGE_ATTR);
    }


    @Override
    public void toXML(Node parent) {
        Document owner = parent.getOwnerDocument();
        Element   axis = owner.createElement("axis");

        parent.appendChild(axis);

        for (String key: getKeys()) {
            Attribute attr = getAttribute(key);
            attr.toXML(axis);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
